@@ -882,7 +882,6 @@ class RegisterStepExecution:
         session = self.Session()
         try:
             yield session
-            session.flush()
             session.commit()
         except:
             session.rollback()
@@ -1126,13 +1125,13 @@ def _deploy_orchestration(orchestration: Orchestration,
     # convert UUID into str as in_ filter does not handle UUID type
     all = [str(s) for s in hosts['all']]
     servers = Server.query.filter(Server.id.in_(all)).all()
-    try:
-        applicant = lock.lock(Scope.ORCHESTRATION, servers, applicant=var_context.env.get('root_orch_execution_id'),
-                              retries=lock_retries, delay=lock_delay)
-    except errors.LockError as e:
-        kwargs.update(success=False, message=str(e))
-        rse.update_orch_execution(**kwargs)
-        raise
+    # try:
+    #     applicant = lock.lock(Scope.ORCHESTRATION, servers, applicant=var_context.env.get('root_orch_execution_id'),
+    #                           retries=lock_retries, delay=lock_delay)
+    # except errors.LockError as e:
+    #     kwargs.update(success=False, message=str(e))
+    #     rse.update_orch_execution(**kwargs)
+    #     raise
     try:
         kwargs['success'] = cc.invoke(timeout=timeout)
         if not kwargs['success'] and orchestration.undo_on_error:
@@ -1148,7 +1147,7 @@ def _deploy_orchestration(orchestration: Orchestration,
         except:
             pass
 
-    finally:
-        lock.unlock(Scope.ORCHESTRATION, applicant=applicant, servers=servers)
+    # finally:
+    #     lock.unlock(Scope.ORCHESTRATION, applicant=applicant, servers=servers)
 
     return execution.id
