@@ -3,7 +3,7 @@ from flask_jwt_extended import jwt_required
 from flask_restful import Resource
 
 from dimensigon.domain.entities.user import User
-from dimensigon.web import db
+from dimensigon.web import db, errors
 from dimensigon.web.decorators import forward_or_dispatch, securizer, validate_schema, lock_catalog
 from dimensigon.web.helpers import filter_query
 from dimensigon.web.json_schemas import users_post, user_patch
@@ -26,6 +26,8 @@ class UserList(Resource):
     def post(self):
         data = request.get_json()
         password = data.pop("password")
+        if User.query.filter_by(name=data['name']).all():
+            raise errors.EntityAlreadyExists("User", data['name'], ['name'])
         u = User(**data)
         u.set_password(password)
         db.session.add(u)
@@ -38,7 +40,7 @@ class UserResource(Resource):
     @jwt_required
     @securizer
     def get(self, user_id):
-        return User.query.get_or_404(user_id).to_json()
+        return User.query.get_or_raise(user_id).to_json()
 
     @forward_or_dispatch()
     @jwt_required
@@ -46,7 +48,7 @@ class UserResource(Resource):
     @validate_schema(user_patch)
     @lock_catalog
     def patch(self, user_id):
-        user = User.query.get_or_404(user_id)
+        user = User.query.get_or_raise(user_id)
         data = request.get_json()
         if 'email' in data and user.email != data.get('email'):
             user.email = data.get('email')
@@ -61,7 +63,7 @@ class UserResource(Resource):
     # @jwt_required
     # @forward_or_dispatch()
     # def delete(self, user_id):
-    #     user = User.query.get_or_404(user_id)
+    #     user = User.query.get_or_raise(user_id)
     #     db.session.delete(user)
     #     db.session.commit()
     #     return {}, 204
